==> haskell-cairo-0.13.8.1-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cairo
version:              0.13.8.1
visibility:           public
id:                   cairo-0.13.8.1-6X2KgYg81k7LDp7JRBDPJM
key:                  cairo-0.13.8.1-6X2KgYg81k7LDp7JRBDPJM
license:              BSD-3-Clause
copyright:
    (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:             Graphics
abi:                  fc232bee07e5a0d8898454173a4e00a8
exposed:              True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types

hidden-modules:
    Graphics.Rendering.Cairo.Internal.Drawing.Cairo
    Graphics.Rendering.Cairo.Internal.Drawing.Paths
    Graphics.Rendering.Cairo.Internal.Drawing.Patterns
    Graphics.Rendering.Cairo.Internal.Drawing.Text
    Graphics.Rendering.Cairo.Internal.Drawing.Transformations
    Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
    Graphics.Rendering.Cairo.Internal.Surfaces.Image
    Graphics.Rendering.Cairo.Internal.Surfaces.PNG
    Graphics.Rendering.Cairo.Internal.Surfaces.Surface
    Graphics.Rendering.Cairo.Internal.Utilities
    Graphics.Rendering.Cairo.Internal.Surfaces.PDF
    Graphics.Rendering.Cairo.Internal.Surfaces.PS
    Graphics.Rendering.Cairo.Internal.Surfaces.SVG
    Graphics.Rendering.Cairo.Internal.Region

import-dirs:          /usr/lib/ghc-9.0.1/site-local/cairo-0.13.8.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cairo-0.13.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cairo
hs-libraries:         HScairo-0.13.8.1-6X2KgYg81k7LDp7JRBDPJM
extra-libraries:      cairo png16 z
include-dirs:
    /usr/include/cairo /usr/include/lzo /usr/include/libpng16
    /usr/include/freetype2 /usr/include/harfbuzz /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/pixman-1

depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 mtl-2.2.2
    text-1.2.4.1 utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf

haddock-interfaces:   /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html:         /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cairo-0.13.8.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cairo
version:              0.13.8.2
visibility:           public
id:                   cairo-0.13.8.2-5ej5gttQEUYEzkJECOd4uO
key:                  cairo-0.13.8.2-5ej5gttQEUYEzkJECOd4uO
license:              BSD-3-Clause
copyright:
    (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:             Graphics
abi:                  2aa8b9322e942dfe5b0a337699e5a565
exposed:              True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types

hidden-modules:
    Graphics.Rendering.Cairo.Internal.Drawing.Cairo
    Graphics.Rendering.Cairo.Internal.Drawing.Paths
    Graphics.Rendering.Cairo.Internal.Drawing.Patterns
    Graphics.Rendering.Cairo.Internal.Drawing.Text
    Graphics.Rendering.Cairo.Internal.Drawing.Transformations
    Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
    Graphics.Rendering.Cairo.Internal.Surfaces.Image
    Graphics.Rendering.Cairo.Internal.Surfaces.PNG
    Graphics.Rendering.Cairo.Internal.Surfaces.Surface
    Graphics.Rendering.Cairo.Internal.Utilities
    Graphics.Rendering.Cairo.Internal.Surfaces.PDF
    Graphics.Rendering.Cairo.Internal.Surfaces.PS
    Graphics.Rendering.Cairo.Internal.Surfaces.SVG
    Graphics.Rendering.Cairo.Internal.Region

import-dirs:          /usr/lib/ghc-9.0.2/site-local/cairo-0.13.8.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cairo-0.13.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cairo
hs-libraries:         HScairo-0.13.8.2-5ej5gttQEUYEzkJECOd4uO
extra-libraries:      z cairo png16
include-dirs:
    /usr/include/cairo /usr/include/lzo /usr/include/libpng16
    /usr/include/freetype2 /usr/include/harfbuzz /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-4
    /usr/include/pixman-1

depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 mtl-2.2.2
    text-1.2.5.0 utf8-string-1.0.2-Fg3PN5UX3ZfnukMwwaDpj

haddock-interfaces:   /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html:         /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
